package com.zanxiang.sdk.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.zanxiang.common.domain.ResultVo;
import com.zanxiang.mybatis.entity.User;
import com.zanxiang.sdk.domain.dto.UserDTO;
import com.zanxiang.sdk.domain.params.*;
import com.zanxiang.sdk.domain.vo.UserLoginVO;

import javax.servlet.http.HttpServletRequest;

/**
 * @author : lingfeng
 * @time : 2022-06-08
 * @description : 用户信息
 */
public interface IUserService extends IService<User> {

    /**
     * 普通注册
     *
     * @param registerPasswordParam : 用户名密码注册参数
     * @return : 返回注册结果
     */
    ResultVo<UserLoginVO> registerPassword(RegisterPasswordParam registerPasswordParam, HttpServletRequest request);

    /**
     * 手机注册
     *
     * @param registerMobileParam : 手机注册参数
     * @param request             : HttpServletRequest
     * @return : 返回注册结果
     */
    ResultVo<UserLoginVO> registerMobile(RegisterMobileParam registerMobileParam, HttpServletRequest request);

    /**
     * 用户名密码登录
     *
     * @param userLoginParam : 登录参数
     * @param request        : HttpServletRequest
     * @return : 返回登录token
     */
    ResultVo<UserLoginVO> loginPassword(LoginPasswordParam userLoginParam, HttpServletRequest request);

    /**
     * 手机号登录
     *
     * @param loginMobileParam : 手机号登录参数
     * @param request          : HttpServletRequest
     * @return : 返回登录信息
     */
    ResultVo<UserLoginVO> loginMobile(LoginMobileParam loginMobileParam, HttpServletRequest request);

    /**
     * 用户重置密码
     *
     * @param updatePasswordParam : 修改密码的参数
     * @return : 返回修改结果
     */
    ResultVo updatePassword(UpdatePasswordParam updatePasswordParam);

    /**
     * 检查用户手机号是否存在
     *
     * @param mobile : 用户手机号
     * @return : 返回用户信息
     */
    UserDTO getUserInfoByMobile(String mobile);
}
